#!/bin/sh
# SPDX-License-Identifier: MIT

error() {
	printf "%s\n" "$@" >&2
	exit 1
}

tmpdir_create() {
	local hint="$1"
	TMPDIR=$(mktemp -d "/var/tmp/swupdate-abosweb-$hint.XXXXXX") \
		|| error "Could not create temporary directory for swupdate"
}

tmpdir_cleanup() {
	if [ -n "$TMPDIR" ]; then
		find "$TMPDIR" -xdev -delete 2>/dev/null
		unset TMPDIR
	fi
}

main() {
	# updates triggered through this are always interactive, so allow rollback
	export SW_ALLOW_ROLLBACK=1

	mode="$1"
	shift

	case "$mode" in
	stdin|url) "swupdate_$mode" "$@";;
	*)
		error "Usage: swupdate.sh [stdin|url <url> [<url>...]]"
		;;
	esac
}

swupdate_stdin() {
	local rc
	tmpdir_create upload
	TMPDIR="$TMPDIR" swupdate -i /proc/self/fd/0
	rc=$?
	tmpdir_cleanup
	# success if rebooting
	[ -e /tmp/.swupdate_rebooting ] && exit
	# otherwise return swupdate status
	return $rc
}

swupdate_url() {
	local rc=0

	# try all urls given
	for url; do
		echo "Downloading $url..."
		tmpdir_create url
		TMPDIR="$TMPDIR" swupdate -d "-u $url"
		rc=$?
		tmpdir_cleanup
		# we're done, don't try more
		[ -e /tmp/.swupdate_rebooting ] && exit
	done
	return $rc
}

main "$@"
