// SPDX-License-Identifier: MIT

use askama::Template;
use axum::{response::IntoResponse, routing::get, Router};

use crate::common::{html_template::HtmlTemplate, side_menu, CheckAuth};

#[derive(Template)]
#[template(path = "../src/top/templates/top.html")]
struct TopTemplate {
    side_menu: &'static [side_menu::SideMenu],
}

pub trait TopRoutes {
    fn top_routes(self) -> Self;
}

impl TopRoutes for Router {
    fn top_routes(self) -> Self {
        self.route("/top", get(top))
    }
}

async fn top(_loggedin: CheckAuth) -> impl IntoResponse {
    let top_template = TopTemplate {
        side_menu: side_menu::side_menu_list(),
    };
    HtmlTemplate::new("トップページ", top_template).into_response()
}
